@@ -1,6 +1,6 @@
 package EBook::Ishmael::EBook::PalmDoc;
 use 5.016;
-our $VERSION = '1.09';
+our $VERSION = '2.00';
 use strict;
 use warnings;
 
@@ -100,25 +100,25 @@ sub new {
         die "$self->{Source} is not a PalmDoc file\n";
     }
 
-    $self->{Metadata}->title([ $self->{_pdb}->name ]);
+    $self->{Metadata}->set_title($self->{_pdb}->name);
 
     if ($self->{_pdb}->cdate) {
-        $self->{Metadata}->created([ scalar gmtime $self->{_pdb}->cdate ]);
+        $self->{Metadata}->set_created($self->{_pdb}->cdate);
     }
     if ($self->{_pdb}->mdate) {
-        $self->{Metadata}->modified([ scalar gmtime $self->{_pdb}->mdate ]);
+        $self->{Metadata}->set_modified($self->{_pdb}->mdate);
     }
 
     if ($self->{_pdb}->version) {
-        $self->{Metadata}->format([
+        $self->{Metadata}->set_format(
             sprintf(
                 "PalmDOC %s.%s",
                 ($self->{_pdb}->version >> 8) & 0xff,
                 $self->{_pdb}->version & 0xff
             )
-        ]);
+        );
     } else {
-        $self->{Metadata}->format([ 'PalmDOC' ]);
+        $self->{Metadata}->set_format('PalmDOC');
     }
 
     return $self;
@@ -177,7 +177,7 @@ sub metadata {
 
     my $self = shift;
 
-    return $self->{Metadata}->hash;
+    return $self->{Metadata};
 
 }
 
